@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2021 Mike Fährmann
+# Copyright 2021-2023 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -12,7 +12,6 @@ from .common import Extractor, Message
 from .. import text, util, exception
 from ..cache import cache
 import itertools
-import time
 
 BASE_PATTERN = r"(?:https?://)?(?:www\.)?erome\.com"
 
@@ -66,7 +65,7 @@ class EromeExtractor(Extractor):
     def request(self, url, **kwargs):
         if self.__cookies:
             self.__cookies = False
-            self.session.cookies.update(_cookie_cache())
+            self.cookies.update(_cookie_cache())
 
         for _ in range(5):
             response = Extractor.request(self, url, **kwargs)
@@ -75,13 +74,13 @@ class EromeExtractor(Extractor):
             if response.content.find(
                     b"<title>Please wait a few moments</title>", 0, 600) < 0:
                 return response
-            time.sleep(5)
+            self.sleep(5.0, "check")
 
     def _pagination(self, url, params):
         for params["page"] in itertools.count(1):
             page = self.request(url, params=params).text
 
-            album_ids = EromeAlbumExtractor.pattern.findall(page)
+            album_ids = EromeAlbumExtractor.pattern.findall(page)[::2]
             yield from album_ids
 
             if len(album_ids) < 36:
@@ -92,16 +91,7 @@ class EromeAlbumExtractor(EromeExtractor):
     """Extractor for albums on erome.com"""
     subcategory = "album"
     pattern = BASE_PATTERN + r"/a/(\w+)"
-    test = ("https://www.erome.com/a/TyFMI7ik", {
-        "pattern": r"https://s\d+\.erome\.com/\d+/TyFMI7ik/\w+",
-        "count": 9,
-        "keyword": {
-            "album_id": "TyFMI7ik",
-            "num": int,
-            "title": "Ryan Ryans",
-            "user": "xanub",
-        },
-    })
+    example = "https://www.erome.com/a/ID"
 
     def albums(self):
         return (self.item,)
@@ -110,10 +100,7 @@ class EromeAlbumExtractor(EromeExtractor):
 class EromeUserExtractor(EromeExtractor):
     subcategory = "user"
     pattern = BASE_PATTERN + r"/(?!a/|search\?)([^/?#]+)"
-    test = ("https://www.erome.com/xanub", {
-        "range": "1-25",
-        "count": 25,
-    })
+    example = "https://www.erome.com/USER"
 
     def albums(self):
         url = "{}/{}".format(self.root, self.item)
@@ -123,10 +110,7 @@ class EromeUserExtractor(EromeExtractor):
 class EromeSearchExtractor(EromeExtractor):
     subcategory = "search"
     pattern = BASE_PATTERN + r"/search\?q=([^&#]+)"
-    test = ("https://www.erome.com/search?q=cute", {
-        "range": "1-25",
-        "count": 25,
-    })
+    example = "https://www.erome.com/search?q=QUERY"
 
     def albums(self):
         url = self.root + "/search"
