@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2014-2022 Mike Fährmann
+# Copyright 2014-2023 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -21,28 +21,30 @@ class ExhentaiExtractor(Extractor):
     """Base class for exhentai extractors"""
     category = "exhentai"
     directory_fmt = ("{category}", "{gid} {title[:247]}")
-    filename_fmt = (
-        "{gid}_{num:>04}_{image_token}_{filename}.{extension}")
+    filename_fmt = "{gid}_{num:>04}_{image_token}_{filename}.{extension}"
     archive_fmt = "{gid}_{num}"
-    cookienames = ("ipb_member_id", "ipb_pass_hash")
-    cookiedomain = ".exhentai.org"
+    cookies_domain = ".exhentai.org"
+    cookies_names = ("ipb_member_id", "ipb_pass_hash")
     root = "https://exhentai.org"
     request_interval = 5.0
 
     LIMIT = False
 
     def __init__(self, match):
-        # allow calling 'self.config()' before 'Extractor.__init__()'
-        self._cfgpath = ("extractor", self.category, self.subcategory)
+        Extractor.__init__(self, match)
+        self.version = match.group(1)
 
-        version = match.group(1)
+    def initialize(self):
         domain = self.config("domain", "auto")
         if domain == "auto":
-            domain = ("ex" if version == "ex" else "e-") + "hentai.org"
+            domain = ("ex" if self.version == "ex" else "e-") + "hentai.org"
         self.root = "https://" + domain
-        self.cookiedomain = "." + domain
+        self.cookies_domain = "." + domain
 
-        Extractor.__init__(self, match)
+        Extractor.initialize(self)
+
+        if self.version != "ex":
+            self.cookies.set("nw", "1", domain=self.cookies_domain)
         self.original = self.config("original", True)
 
         limits = self.config("limits", False)
@@ -52,14 +54,10 @@ class ExhentaiExtractor(Extractor):
         else:
             self.limits = False
 
-        self.session.headers["Referer"] = self.root + "/"
-        if version != "ex":
-            self.session.cookies.set("nw", "1", domain=self.cookiedomain)
-
-    def request(self, *args, **kwargs):
-        response = Extractor.request(self, *args, **kwargs)
-        if self._is_sadpanda(response):
-            self.log.info("sadpanda.jpg")
+    def request(self, url, **kwargs):
+        response = Extractor.request(self, url, **kwargs)
+        if response.history and response.headers.get("Content-Length") == "0":
+            self.log.info("blank page")
             raise exception.AuthorizationError()
         return response
 
@@ -67,17 +65,20 @@ class ExhentaiExtractor(Extractor):
         """Login and set necessary cookies"""
         if self.LIMIT:
             raise exception.StopExtraction("Image limit reached!")
-        if self._check_cookies(self.cookienames):
+
+        if self.cookies_check(self.cookies_names):
             return
+
         username, password = self._get_auth_info()
         if username:
-            self._update_cookies(self._login_impl(username, password))
-        else:
-            self.log.info("no username given; using e-hentai.org")
-            self.root = "https://e-hentai.org"
-            self.original = False
-            self.limits = False
-            self.session.cookies["nw"] = "1"
+            return self.cookies_update(self._login_impl(username, password))
+
+        self.log.info("no username given; using e-hentai.org")
+        self.root = "https://e-hentai.org"
+        self.cookies_domain = ".e-hentai.org"
+        self.cookies.set("nw", "1", domain=self.cookies_domain)
+        self.original = False
+        self.limits = False
 
     @cache(maxage=90*24*3600, keyarg=1)
     def _login_impl(self, username, password):
@@ -98,15 +99,7 @@ class ExhentaiExtractor(Extractor):
         response = self.request(url, method="POST", headers=headers, data=data)
         if b"You are now logged in as:" not in response.content:
             raise exception.AuthenticationError()
-        return {c: response.cookies[c] for c in self.cookienames}
-
-    @staticmethod
-    def _is_sadpanda(response):
-        """Return True if the response object contains a sad panda"""
-        return (
-            response.headers.get("Content-Length") == "9615" and
-            "sadpanda.jpg" in response.headers.get("Content-Disposition", "")
-        )
+        return {c: response.cookies[c] for c in self.cookies_names}
 
 
 class ExhentaiGalleryExtractor(ExhentaiExtractor):
@@ -115,57 +108,7 @@ class ExhentaiGalleryExtractor(ExhentaiExtractor):
     pattern = (BASE_PATTERN +
                r"(?:/g/(\d+)/([\da-f]{10})"
                r"|/s/([\da-f]{10})/(\d+)-(\d+))")
-    test = (
-        ("https://exhentai.org/g/1200119/d55c44d3d0/", {
-            "keyword": {
-                "cost": int,
-                "date": "dt:2018-03-18 20:15:00",
-                "eh_category": "Non-H",
-                "expunged": False,
-                "favorites": r"re:^[12]\d$",
-                "filecount": "4",
-                "filesize": 1488978,
-                "gid": 1200119,
-                "height": int,
-                "image_token": "re:[0-9a-f]{10}",
-                "lang": "ja",
-                "language": "Japanese",
-                "parent": "",
-                "rating": r"re:\d\.\d+",
-                "size": int,
-                "tags": [
-                    "parody:komi-san wa komyushou desu.",
-                    "character:shouko komi",
-                    "group:seventh lowlife",
-                    "other:sample",
-                ],
-                "thumb": "https://exhentai.org/t/ce/0a/ce0a5bcb583229a9b07c0f8"
-                         "3bcb1630ab1350640-624622-736-1036-jpg_250.jpg",
-                "title": "C93 [Seventh_Lowlife] Komi-san ha Tokidoki Daitan de"
-                         "su (Komi-san wa Komyushou desu) [Sample]",
-                "title_jpn": "(C93) [Comiketjack (わ！)] 古見さんは、時々大胆"
-                             "です。 (古見さんは、コミュ症です。) [見本]",
-                "token": "d55c44d3d0",
-                "torrentcount": "0",
-                "uploader": "klorpa",
-                "width": int,
-            },
-            "content": "e9891a4c017ed0bb734cd1efba5cd03f594d31ff",
-        }),
-        ("https://exhentai.org/g/960461/4f0e369d82/", {
-            "exception": exception.NotFoundError,
-        }),
-        ("http://exhentai.org/g/962698/7f02358e00/", {
-            "exception": exception.AuthorizationError,
-        }),
-        ("https://exhentai.org/s/f68367b4c8/1200119-3", {
-            "count": 2,
-        }),
-        ("https://e-hentai.org/s/f68367b4c8/1200119-3", {
-            "count": 2,
-        }),
-        ("https://g.e-hentai.org/g/1200119/d55c44d3d0/"),
-    )
+    example = "https://e-hentai.org/g/12345/67890abcde/"
 
     def __init__(self, match):
         ExhentaiExtractor.__init__(self, match)
@@ -176,16 +119,31 @@ class ExhentaiGalleryExtractor(ExhentaiExtractor):
         self.image_token = match.group(4)
         self.image_num = text.parse_int(match.group(6), 1)
 
+    def _init(self):
         source = self.config("source")
         if source == "hitomi":
             self.items = self._items_hitomi
 
+    def favorite(self, slot="0"):
+        url = self.root + "/gallerypopups.php"
+        params = {
+            "gid": self.gallery_id,
+            "t"  : self.gallery_token,
+            "act": "addfav",
+        }
+        data = {
+            "favcat" : slot,
+            "apply"  : "Apply Changes",
+            "update" : "1",
+        }
+        self.request(url, method="POST", params=params, data=data)
+
     def items(self):
         self.login()
 
         if self.gallery_token:
             gpage = self._gallery_page()
-            self.image_token = text.extract(gpage, 'hentai.org/s/', '"')[0]
+            self.image_token = text.extr(gpage, 'hentai.org/s/', '"')
             if not self.image_token:
                 self.log.error("Failed to extract initial image token")
                 self.log.debug("Page content:\n%s", gpage)
@@ -193,7 +151,7 @@ class ExhentaiGalleryExtractor(ExhentaiExtractor):
             ipage = self._image_page()
         else:
             ipage = self._image_page()
-            part = text.extract(ipage, 'hentai.org/g/', '"')[0]
+            part = text.extr(ipage, 'hentai.org/g/', '"')
             if not part:
                 self.log.error("Failed to extract gallery token")
                 self.log.debug("Page content:\n%s", ipage)
@@ -224,6 +182,10 @@ class ExhentaiGalleryExtractor(ExhentaiExtractor):
                 data["_http_validate"] = None
             yield Message.Url, url, data
 
+        fav = self.config("fav")
+        if fav is not None:
+            self.favorite(fav)
+
     def _items_hitomi(self):
         if self.config("metadata", False):
             data = self.metadata_from_api()
@@ -271,8 +233,8 @@ class ExhentaiGalleryExtractor(ExhentaiExtractor):
         }
 
         if data["uploader"].startswith("<"):
-            data["uploader"] = text.unescape(text.extract(
-                data["uploader"], ">", "<")[0])
+            data["uploader"] = text.unescape(text.extr(
+                data["uploader"], ">", "<"))
 
         f = data["favorites"][0]
         if f == "N":
@@ -395,12 +357,13 @@ class ExhentaiGalleryExtractor(ExhentaiExtractor):
         url = "https://e-hentai.org/home.php"
         cookies = {
             cookie.name: cookie.value
-            for cookie in self.session.cookies
-            if cookie.domain == self.cookiedomain and cookie.name != "igneous"
+            for cookie in self.cookies
+            if cookie.domain == self.cookies_domain and
+            cookie.name != "igneous"
         }
 
         page = self.request(url, cookies=cookies).text
-        current = text.extract(page, "<strong>", "</strong>")[0]
+        current = text.extr(page, "<strong>", "</strong>")
         self.log.debug("Image Limits: %s/%s", current, self.limits)
         self._remaining = self.limits - text.parse_int(current)
 
@@ -463,22 +426,10 @@ class ExhentaiSearchExtractor(ExhentaiExtractor):
     """Extractor for exhentai search results"""
     subcategory = "search"
     pattern = BASE_PATTERN + r"/(?:\?([^#]*)|tag/([^/?#]+))"
-    test = (
-        ("https://e-hentai.org/?f_search=touhou"),
-        ("https://exhentai.org/?f_cats=767&f_search=touhou"),
-        ("https://exhentai.org/tag/parody:touhou+project"),
-        (("https://exhentai.org/?f_doujinshi=0&f_manga=0&f_artistcg=0"
-          "&f_gamecg=0&f_western=0&f_non-h=1&f_imageset=0&f_cosplay=0"
-          "&f_asianporn=0&f_misc=0&f_search=touhou&f_apply=Apply+Filter"), {
-            "pattern": ExhentaiGalleryExtractor.pattern,
-            "range": "1-30",
-            "count": 30,
-        }),
-    )
+    example = "https://e-hentai.org/?f_search=QUERY"
 
     def __init__(self, match):
         ExhentaiExtractor.__init__(self, match)
-        self.search_url = self.root
 
         _, query, tag = match.groups()
         if tag:
@@ -490,41 +441,49 @@ class ExhentaiSearchExtractor(ExhentaiExtractor):
             self.params = {"f_search": tag, "page": 0}
         else:
             self.params = text.parse_query(query)
-            self.params["page"] = text.parse_int(self.params.get("page"))
+            if "next" not in self.params:
+                self.params["page"] = text.parse_int(self.params.get("page"))
+
+    def _init(self):
+        self.search_url = self.root
 
     def items(self):
         self.login()
         data = {"_extractor": ExhentaiGalleryExtractor}
+        search_url = self.search_url
+        params = self.params
 
         while True:
             last = None
-            page = self.request(self.search_url, params=self.params).text
+            page = self.request(search_url, params=params).text
 
             for gallery in ExhentaiGalleryExtractor.pattern.finditer(page):
                 url = gallery.group(0)
                 if url == last:
                     continue
                 last = url
+                data["gallery_id"] = text.parse_int(gallery.group(2))
+                data["gallery_token"] = gallery.group(3)
                 yield Message.Queue, url + "/", data
 
-            if 'class="ptdd">&gt;<' in page or ">No hits found</p>" in page:
+            next_url = text.extr(page, 'nexturl="', '"', None)
+            if next_url is not None:
+                if not next_url:
+                    return
+                search_url = next_url
+                params = None
+
+            elif 'class="ptdd">&gt;<' in page or ">No hits found</p>" in page:
                 return
-            self.params["page"] += 1
+            else:
+                params["page"] += 1
 
 
 class ExhentaiFavoriteExtractor(ExhentaiSearchExtractor):
     """Extractor for favorited exhentai galleries"""
     subcategory = "favorite"
     pattern = BASE_PATTERN + r"/favorites\.php(?:\?([^#]*)())?"
-    test = (
-        ("https://e-hentai.org/favorites.php", {
-            "count": 1,
-            "pattern": r"https?://e-hentai\.org/g/1200119/d55c44d3d0"
-        }),
-        ("https://exhentai.org/favorites.php?favcat=1&f_search=touhou"
-         "&f_apply=Search+Favorites"),
-    )
+    example = "https://e-hentai.org/favorites.php"
 
-    def __init__(self, match):
-        ExhentaiSearchExtractor.__init__(self, match)
+    def _init(self):
         self.search_url = self.root + "/favorites.php"
