@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2018-2022 Mike Fährmann
+# Copyright 2018-2023 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -48,18 +48,7 @@ class KomikcastBase():
 class KomikcastChapterExtractor(KomikcastBase, ChapterExtractor):
     """Extractor for manga-chapters from komikcast.site"""
     pattern = BASE_PATTERN + r"(/chapter/[^/?#]+/)"
-    test = (
-        (("https://komikcast.site/chapter"
-          "/apotheosis-chapter-02-2-bahasa-indonesia/"), {
-            "url": "f6b43fbc027697749b3ea1c14931c83f878d7936",
-            "keyword": "f3938e1aff9ad1f302f52447e9781b21f6da26d4",
-        }),
-        (("https://komikcast.me/chapter"
-          "/soul-land-ii-chapter-300-1-bahasa-indonesia/"), {
-            "url": "efd00a9bd95461272d51990d7bc54b79ff3ff2e6",
-            "keyword": "cb646cfed3d45105bd645ab38b2e9f7d8c436436",
-        }),
-    )
+    example = "https://komikcast.site/chapter/TITLE/"
 
     def metadata(self, page):
         info = text.extr(page, "<title>", " - Komikcast<")
@@ -79,13 +68,7 @@ class KomikcastMangaExtractor(KomikcastBase, MangaExtractor):
     """Extractor for manga from komikcast.site"""
     chapterclass = KomikcastChapterExtractor
     pattern = BASE_PATTERN + r"(/(?:komik/)?[^/?#]+)/?$"
-    test = (
-        ("https://komikcast.site/komik/090-eko-to-issho/", {
-            "url": "19d3d50d532e84be6280a3d61ff0fd0ca04dd6b4",
-            "keyword": "837a7e96867344ff59d840771c04c20dc46c0ab1",
-        }),
-        ("https://komikcast.me/tonari-no-kashiwagi-san/"),
-    )
+    example = "https://komikcast.site/komik/TITLE"
 
     def chapters(self, page):
         results = []
